==> breeze_website_builder_6.5.02.tar.gz: manage/plugins/lang/gallery/bn.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "লাইটবক্স গ্যালারি পরামিতি পরিচালনা");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "গ্যালারি পরিচালনা");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "পূর্ণ আকার চিত্র প্রস্থ");
define('MANAGE_GALLERY_FULL_HEIGHT', "পূর্ণ আকার চিত্র উচ্চতা");
define('MANAGE_GALLERY_THUMB_WIDTH', "থাম্বনেল চিত্র প্রস্থ");
define('MANAGE_GALLERY_THUMB_HEIGHT', "থাম্বনেল চিত্র উচ্চতা");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "সংরক্ষণ বুড়ো অনুপাত");
define('MANAGE_GALLERY_SHOW_TITLES', "দেখান নমুনা এ থেকে জেড");
define('MANAGE_GALLERY_DISABLE_SORT', "নিষ্ক্রিয় সাজান");
define('MANAGE_GALLERY_DELETE_IMAGE', "চিত্র মুছুন");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "সাজানোর ক্রম সংরক্ষণ");
define('MANAGE_GALLERY_PUBLISH_MSG', "প্রকাশ করতে ক্লিক করুন &#39;আপডেট&#39; <br /> আপনার আপলোড করা ইমেজ.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "সকল ইমেজ মাপ পরিবর্তন করা হয়েছে এবং সেটিংস সংরক্ষণ করা হয়েছে.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "ইমেজ resizing বা সেটিংস সংরক্ষণ করার সময় একটি ত্রুটি হয়েছিল.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "আপনার ইমেজ (গুলি) আপলোড করা হয়েছে.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "আপনার ইমেজ (গুলি) আপলোড করার সময় একটি ত্রুটি হয়েছিল.");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "আপনি যে ফাইলটি আপলোড করার চেষ্টা করছেন একটি চিত্র নয়.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "আপনি যে ফাইলটি আপলোড করার চেষ্টা করছেন অত্যন্ত বড়.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "শিরোনাম সংরক্ষণ করা হয়েছে.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "আপনি কি নিশ্চিত যে আপনি ইমেজ মুছে দিতে চান");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "ইমেজ মুছে ফেলা হয়েছে.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "ইমেজ মোছার সময় একটি ত্রুটি হয়েছিল.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "পরামিতি সংরক্ষণ এবং ইমেজ resizing, অনুগ্রহ করে অপেক্ষা করুন ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "আপলোড, অনুগ্রহ করে অপেক্ষা করুন ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "সাজানোর ক্রম সংরক্ষিত হয়নি. আপনি সাজানোর ক্রম সংরক্ষণ করতে চান না?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "ইমেজ সাজানোর ক্রম সংরক্ষণ করা হয়েছে.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "ইমেজ সাজানোর সংরক্ষিণ করতে সমস্যা ছিল.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/bn.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "লাইটবক্স গ্যালারি পরামিতি পরিচালনা");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "গ্যালারি পরিচালনা");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "পূর্ণ আকার চিত্র প্রস্থ");
define('MANAGE_GALLERY_FULL_HEIGHT', "পূর্ণ আকার চিত্র উচ্চতা");
define('MANAGE_GALLERY_THUMB_WIDTH', "থাম্বনেল চিত্র প্রস্থ");
define('MANAGE_GALLERY_THUMB_HEIGHT', "থাম্বনেল চিত্র উচ্চতা");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "সংরক্ষণ বুড়ো অনুপাত");
define('MANAGE_GALLERY_SHOW_TITLES', "দেখান নমুনা এ থেকে জেড");
define('MANAGE_GALLERY_DISABLE_SORT', "নিষ্ক্রিয় সাজান");
define('MANAGE_GALLERY_DELETE_IMAGE', "চিত্র মুছুন");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "সাজানোর ক্রম সংরক্ষণ");
define('MANAGE_GALLERY_PUBLISH_MSG', "প্রকাশ করতে ক্লিক করুন &#39;আপডেট&#39; <br /> আপনার আপলোড করা ইমেজ.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "সকল ইমেজ মাপ পরিবর্তন করা হয়েছে এবং সেটিংস সংরক্ষণ করা হয়েছে.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "ইমেজ resizing বা সেটিংস সংরক্ষণ করার সময় একটি ত্রুটি হয়েছিল.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "আপনার ইমেজ (গুলি) আপলোড করা হয়েছে.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "আপনার ইমেজ (গুলি) আপলোড করার সময় একটি ত্রুটি হয়েছিল.");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "আপনি যে ফাইলটি আপলোড করার চেষ্টা করছেন একটি চিত্র নয়.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "আপনি যে ফাইলটি আপলোড করার চেষ্টা করছেন অত্যন্ত বড়.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "শিরোনাম সংরক্ষণ করা হয়েছে.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "আপনি কি নিশ্চিত যে আপনি ইমেজ মুছে দিতে চান");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "ইমেজ মুছে ফেলা হয়েছে.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "ইমেজ মোছার সময় একটি ত্রুটি হয়েছিল.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "পরামিতি সংরক্ষণ এবং ইমেজ resizing, অনুগ্রহ করে অপেক্ষা করুন ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "আপলোড, অনুগ্রহ করে অপেক্ষা করুন ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "সাজানোর ক্রম সংরক্ষিত হয়নি. আপনি সাজানোর ক্রম সংরক্ষণ করতে চান না?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "ইমেজ সাজানোর ক্রম সংরক্ষণ করা হয়েছে.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "ইমেজ সাজানোর সংরক্ষিণ করতে সমস্যা ছিল.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "আপনি যে ফাইলটি আপলোড করার চেষ্টা করছেন সেটি &#39;আপলোড_ম্যাক্স_ফাইলেজ&#39; বা &#39;পোস্ট_ম্যাক্স_সাইজ&#39; পিএইচপি সেটিংসের চেয়ে বড়। এই সীমাবদ্ধতাগুলি বাড়ানোর জন্য আপনার সিস্টেম প্রশাসকের সাথে যোগাযোগ করুন।");
?>
